#
# spec file for package libzbc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libzbc
%define lname   libzbc-5_5_0
Version:        5.5.0
Release:        lp150.1.1
Summary:        Library for manipulating ZBC and ZAC disks
License:        BSD-2-Clause AND LGPL-3.0-or-later
Group:          Hardware/Other
Url:            http://github.com/hgst/libzbc

Source:         https://github.com/hgst/libzbc/archive/v%version.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libtool >= 2
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(gtk+-3.0)

%description
libzbc is a simple library providing functions for manipulating Zoned
Block Command (ZBC) and Zoned-device ATA command set (ZAC) disks.
libzbc also has an mode for emulating the behavior of a zoned disk
using a regular file or raw block device.

%package -n %lname
Summary:        Library for manipulating ZBC and ZAC disks
Group:          System/Libraries

%description -n %lname
libzbc is a simple library providing functions for manipulating Zoned
Block Command (ZBC) and Zoned-device ATA command set (ZAC) disks.
libzbc also has an mode for emulating the behavior of a zoned disk
using a regular file or raw block device.

%package devel
Summary:        Development files for libzbc, a ZBC/ZAC disk manipulation library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libzbc is a simple library providing functions for manipulating Zoned
Block Command (ZBC), Zoned-device ATA command set (ZAC) disks.

This subpackage contains the files needed to build against libzbc.

%package gui
Summary:        Graphical frontend for ZBC tools
Group:          Hardware/Other

%description gui
A simple graphical interface showing zone information of a zoned device.
It also displays the write status (write pointer position) of zones
graphically using color coding (red for written space and green for
unwritten space). 

%package tools
Summary:        Command line utilities for ZBC/ZAC disk manipulation
Group:          Hardware/Other

%description tools
libzbc is a simple library providing functions for manipulating Zoned
Block Command (ZBC), Zoned-device ATA command set (ZAC) disks.

%prep
%setup -q

%build
autoreconf -fi
mkdir obj
pushd obj/
%define _configure ../configure
%configure --disable-static --includedir="%_includedir/%name"
make %{?_smp_mflags}
popd

%install
%make_install -C obj
find "%buildroot/%_libdir" -type f -name "*.la" -delete

%check
make -C obj check %{?_smp_mflags}

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files tools
%defattr(-,root,root)
%_bindir/zbc_*
%doc COPYING.LESSER

%files gui
%defattr(-,root,root)
%_bindir/gzbc

%files -n %lname
%defattr(-,root,root)
%_libdir/libzbc-*.so
%doc COPYING

%files devel
%defattr(-,root,root)
%_includedir/%name/
%_libdir/libzbc.so
%_libdir/pkgconfig/libzbc.pc

%changelog
* Sun Mar 18 2018 jengelh@inai.de
- Update to new upstream release 5.5.0
  * Fixed various problems with the fake backend driver
    (emulation mode), in particular when using a 4K sector disk
    as backend storage.
  * Properly set up direct I/O operation with the SG_IO interface
    (SCSI and ATA backend drivers).
  * Properly handle the maximum and optimal number of open zones
    for drives with no limit and drives not reporting any limit.
  * Skip open zone resource tests for drives with no limit or an
    unreported limit on the maximum/optimal number of open zones.
  * Add a new test to verify that a drive returns the correct
    ASC/ASCQ sense error codes when writing to a full zone (HM
    drives only).
* Tue Aug  8 2017 jengelh@inai.de
- Update to new upstream release 5.3.1
  * A rewrite of libzbc introducing significant changes to the
    API. Support for draft standards 4.x is dropped. Compliance
    to the final ZBC/ZAC standards is improved.
  * All functions now operate using 512B sector units, regardless
    of the device actual logical block size. This is in line with
    Linux block device management and can simplify application
    implementation by unifying the addressing unit used when
    devices with different logical block sizes (512B or 4096B)
    are being used. Applications must however still comply with
    write request alignment to the device physical block size,
    which may be different from the 512B sector size unit used.
  * Improved read and write functions (zbc_pread and zbc_pwrite)
    to not limit the request size to the device maximum request
    data transfer size (calls are internally split into multiple
    requests).
* Tue Nov 29 2016 jengelh@inai.de
- Update to new upstream release 4.3.3
  * block backend driver: support latest "official" kernel
    interface queued up for kernel 4.10 release.
* Thu Sep 29 2016 jengelh@inai.de
- Update to new upstream release 4.3.0
  * Properly handle detection of zoned block devices using sysfs
  * Fixed handling of list view so that an operation on a zone does
  not reset the current selection and view whenever possible.
  * Improved handling of the list view using a filter model.
  * Added support for direct I/Os (O_DIRECT). Note: this does not
  work with SG node device files.
  * Added maximum read/write command size in the device info
  structure.
  * Initialize maximum device read/write I/O size for each backend
  driver.
  * Check read/write command size against the maximum allowed for
  the device.
  * Fixed get capacity: the code is now common for ATA and SCSI.
  This fixes problems in SCSI backend when RC_BASIS is 0 (report
  zones was being executed without the max logical sectors being
  set), and also adds RC_BASIS handling for ATA drives (this was
  missing entirely).
* Fri Jul  1 2016 jengelh@inai.de
- Update to new upstream release 4.1.1
  * This release implements support for ZBC and ZAC revision 4 and
  above draft standards.
  * Fixed the fake backend driver to pass all tests even if the
  device specified is very small (i.e. it has only a few sequential
  zones).
  * Display SG_IO ioctl error message only when the log level is set
  to debug/verbose.
* Sat Feb 13 2016 jengelh@inai.de
- Update to new git snapshot 2.0.0.g32
  * Support for ZBC and ZAC r04
  * Added block device backend driver for use with kernels providing
  SMR support and exposing host-managed disks as block devices.
* Thu Nov 12 2015 jengelh@inai.de
- Update to new git snapshot 2.0.0~git113
  * Added sense key and sense code string, DATA PROTECT and ZONE IS READ ONLY.
  * Added filling sense key/sense code when reads spanning other types of zone.
  * Supported storing ASC/ASCQ data on ata.
  * Supported URSWRZ flag on SCSi.
  * Added flags in zbc_device_info structure and stored URSWRZ flag in it.
  * Added forced ata read/write flag to read/write using pass through command.
  * Supported ZBC sense key, ASC/ASCQ handling.
* Mon Jun  8 2015 jengelh@inai.de
- Update to new git snapshot 2.0.0~git65
  * supports the ZBC standard draft Rev 02
  and Rev 01 of the ZAC standard draft
* Mon Mar 16 2015 jengelh@inai.de
- Initial package (version 1.1.0~git68) for build.opensuse.org
